@@ -29,7 +29,7 @@ from typing import Optional
 from typing import Tuple
 
 
-__version__ = '0.0.7'
+__version__ = '0.1.1'
 
 
 DEFAULT_BRANCH = 'master'
@@ -54,22 +54,28 @@ class EnvDefaultOption(argparse.Action):
         self,
         env_var: str,
         default: Any,
-        help=None,  # noqa: A002
-        **kwargs,
+        help: Optional[str] = None,  # noqa: A002
+        **kwargs: Any,
     ) -> None:
-        """Create a EnvDefaultOption."""
+        """Create an EnvDefaultOption."""
         # Set default to env var value if it exists
         if env_var in os.environ:
             default = os.environ[env_var]
         if help:  # pragma: no cover
-            help += f' [env var: {env_var}]'
+            help += f' [env: {env_var}]'
         super(EnvDefaultOption, self).__init__(
             default=default,
             help=help,
             **kwargs,
         )
 
-    def __call__(self, parser, namespace, values, option_string=None):  # noqa
+    def __call__(  # noqa: D102
+        self,
+        parser: argparse.ArgumentParser,
+        namespace: argparse.Namespace,
+        values: Any,
+        option_string: Optional[str] = None,
+    ) -> None:
         setattr(namespace, self.dest, values)
 
 
@@ -82,17 +88,17 @@ class EnvDefaultStoreTrue(argparse.Action):
 
     def __init__(
         self,
-        option_strings,
-        dest,
+        option_strings: str,
+        dest: str,
         env_var: str,
         default: bool = False,
-        help=None,  # noqa: A002
+        help: Optional[str] = None,  # noqa: A002
     ) -> None:
-        """Create a EnvDefaultStoreTrue."""
+        """Create an EnvDefaultStoreTrue."""
         # Set default value to true if the env var exists
         default = env_var in os.environ
         if help:  # pragma: no cover
-            help += f' [env var: {env_var} (set to anything)]'
+            help += f' [env: {env_var} (any value to enable)]'
         super(EnvDefaultStoreTrue, self).__init__(
             option_strings=option_strings,
             dest=dest,
@@ -103,7 +109,13 @@ class EnvDefaultStoreTrue(argparse.Action):
             help=help,
         )
 
-    def __call__(self, parser, namespace, values, option_string=None):  # noqa
+    def __call__(  # noqa: D102
+        self,
+        parser: argparse.ArgumentParser,
+        namespace: argparse.Namespace,
+        values: Any,
+        option_string: Optional[str] = None,
+    ) -> None:
         setattr(namespace, self.dest, self.const)
 
 
@@ -163,6 +175,12 @@ def get_parser() -> argparse.ArgumentParser:
             'verbose mode (print out more information) (default: %(default)s)'
         ),
     )
+    parser.add_argument(
+        '--version',
+        action='version',
+        help='show version number and exit',
+        version=f'dco-check version {__version__}',
+    )
     return parser
 
 
@@ -212,7 +230,7 @@ class Options:
             )
             sys.exit(1)
 
-    def get_options(self) -> Dict:
+    def get_options(self) -> Dict[str, Any]:
         """Get all options as a dict."""
         return self.__dict__
 
@@ -233,12 +251,12 @@ class Logger:
         self.__quiet = options.quiet
         self.__verbose = options.verbose
 
-    def print(self, msg='', *args, **kwargs) -> None:  # noqa: A003
+    def print(self, msg: str = '', *args: Any, **kwargs: Any) -> None:  # noqa: A003
         """Print if not quiet."""
         if not self.__quiet:
             print(msg, *args, **kwargs)
 
-    def verbose_print(self, msg='', *args, **kwargs) -> None:
+    def verbose_print(self, msg: str = '', *args: Any, **kwargs: Any) -> None:
         """Print if verbose."""
         if self.__verbose:
             print(msg, *args, **kwargs)
@@ -258,10 +276,17 @@ def run(
     """
     output = None
     try:
+        env = os.environ.copy()
+        if 'LANG' in env:
+            del env['LANG']
+        for key in list(env.keys()):
+            if key.startswith('LC_'):
+                del env[key]
         process = subprocess.Popen(
             command,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
+            env=env,
         )
         output_stdout, _ = process.communicate()
         if process.returncode != 0:
@@ -285,7 +310,7 @@ def is_valid_email(
     :param email: the email address to check
     :return: true if email is valid, false otherwise
     """
-    return re.match(r'^\S+@\S+\.\S+', email)
+    return bool(re.match(r'^\S+@\S+\.\S+', email))
 
 
 def get_head_commit_hash() -> Optional[str]:
@@ -366,7 +391,7 @@ def get_default_branch_from_remote(
     for result_line in result_lines:
         # There is a two-space indentation
         match = re.match('  HEAD branch: (.*)', result_line)
-        if match is not None:
+        if match:
             branch = match[1]
             break
     return branch
@@ -436,15 +461,29 @@ def extract_name_and_email(
     :return: the extracted (name, email) tuple, or `None` if it failed
     """
     match = re.search('(.*) <(.*)>', name_and_email)
-    if match is None:
+    if not match:
         return None
     return match.group(1), match.group(2)
 
 
+def format_name_and_email(
+    name: Optional[str],
+    email: Optional[str],
+) -> str:
+    """
+    Format a name and a email into a 'name <email>' string.
+
+    :param name: the name, or `None` if N/A
+    :param email: the email, or `None` if N/A
+    :return: the formatted string
+    """
+    return f"{name or 'N/A'} <{email or 'N/A'}>"
+
+
 def get_env_var(
     env_var: str,
     print_if_not_found: bool = True,
-    default: str = None,
+    default: Optional[str] = None,
 ) -> Optional[str]:
     """
     Get the value of an environment variable.
@@ -476,8 +515,8 @@ class CommitInfo:
         commit_hash: str,
         title: str,
         body: List[str],
-        author_name: str,
-        author_email: str,
+        author_name: Optional[str],
+        author_email: Optional[str],
         is_merge_commit: bool = False,
     ) -> None:
         """Create a CommitInfo object."""
@@ -516,7 +555,7 @@ class CommitDataRetriever:
         """
         raise NotImplementedError  # pragma: no cover
 
-    def get_commits(self, base: str, head: str, **kwargs) -> Optional[List[CommitInfo]]:
+    def get_commits(self, base: str, head: str, **kwargs: Any) -> Optional[List[CommitInfo]]:
         """Get commit data."""
         raise NotImplementedError  # pragma: no cover
 
@@ -535,24 +574,26 @@ class GitRetriever(CommitDataRetriever):
         default_branch = options.default_branch
         logger.verbose_print(f"\tusing default branch '{default_branch}'")
         commit_hash_base = get_common_ancestor_commit_hash(default_branch)
-        if commit_hash_base is None:
+        if not commit_hash_base:
             return None
         commit_hash_head = get_head_commit_hash()
-        if commit_hash_head is None:
+        if not commit_hash_head:
             return None
         return commit_hash_base, commit_hash_head
 
-    def get_commits(
+    def get_commits(  # noqa: D102
         self,
         base: str,
         head: str,
         check_merge_commits: bool = False,
-        **kwargs,
-    ) -> Optional[List[CommitInfo]]:  # noqa: D102
+        **kwargs: Any,
+    ) -> Optional[List[CommitInfo]]:
         ignore_merge_commits = not check_merge_commits
         commits_data = get_commits_data(base, head, ignore_merge_commits=ignore_merge_commits)
+        commits: List[CommitInfo] = []
+        if commits_data is None:
+            return commits
         individual_commits = split_commits_data(commits_data)
-        commits = []
         for commit_data in individual_commits:
             commit_lines = commit_data.split('\n')
             commit_hash = commit_lines[0]
@@ -561,7 +602,7 @@ class GitRetriever(CommitDataRetriever):
             commit_body = commit_lines[3:]
             author_result = extract_name_and_email(commit_author_data)
             author_name, author_email = None, None
-            if author_result is not None:
+            if author_result:
                 author_name, author_email = author_result
             # There won't be any merge commits at this point
             is_merge_commit = False
@@ -578,7 +619,7 @@ class GitRetriever(CommitDataRetriever):
         return commits
 
 
-class GitlabRetriever(GitRetriever):
+class GitLabRetriever(GitRetriever):
     """Implementation for GitLab CI."""
 
     def name(self) -> str:  # noqa: D102
@@ -592,47 +633,56 @@ class GitlabRetriever(GitRetriever):
         default_branch = get_env_var('CI_DEFAULT_BRANCH', default=options.default_branch)
 
         commit_hash_head = get_env_var('CI_COMMIT_SHA')
-        if commit_hash_head is None:
+        if not commit_hash_head:
             return None
 
-        # If we're on the default branch, just test new commits
         current_branch = get_env_var('CI_COMMIT_BRANCH')
-        if current_branch is not None and current_branch == default_branch:
+        if get_env_var('CI_PIPELINE_SOURCE') == 'schedule':
+            # Do not check scheduled pipelines
+            logger.verbose_print("\ton scheduled pipeline: won't check commits")
+            return commit_hash_head, commit_hash_head
+        elif current_branch == default_branch:
+            # If we're on the default branch, just test new commits
             logger.verbose_print(
                 f"\ton default branch '{current_branch}': "
                 'will check new commits'
             )
             commit_hash_base = get_env_var('CI_COMMIT_BEFORE_SHA')
-            if commit_hash_base is None:
+            if commit_hash_base == '0000000000000000000000000000000000000000':
+                logger.verbose_print('\tfound no new commits')
+                return commit_hash_head, commit_hash_head
+            if not commit_hash_base:
                 return None
             return commit_hash_base, commit_hash_head
         elif get_env_var('CI_MERGE_REQUEST_ID', print_if_not_found=False):
             # Get merge request target branch
             target_branch = get_env_var('CI_MERGE_REQUEST_TARGET_BRANCH_NAME')
-            if target_branch is None:
+            if not target_branch:
                 return None
             logger.verbose_print(
                 f"\ton merge request branch '{current_branch}': "
                 f"will check new commits off of target branch '{target_branch}'"
             )
             target_branch_sha = get_env_var('CI_MERGE_REQUEST_TARGET_BRANCH_SHA')
-            if target_branch_sha is None:
+            if not target_branch_sha:
                 return None
             return target_branch_sha, commit_hash_head
         elif get_env_var('CI_EXTERNAL_PULL_REQUEST_IID', print_if_not_found=False):
             # Get external merge request target branch
             target_branch = get_env_var('CI_EXTERNAL_PULL_REQUEST_TARGET_BRANCH_NAME')
-            if target_branch is None:
+            if not target_branch:
                 return None
             logger.verbose_print(
                 f"\ton merge request branch '{current_branch}': "
                 f"will check new commits off of target branch '{target_branch}'"
             )
             target_branch_sha = get_env_var('CI_EXTERNAL_PULL_REQUEST_TARGET_BRANCH_SHA')
-            if target_branch_sha is None:
+            if not target_branch_sha:
                 return None
             return target_branch_sha, commit_hash_head
         else:
+            if not default_branch:
+                return None
             # Otherwise test all commits off of the default branch
             logger.verbose_print(
                 f"\ton branch '{current_branch}': "
@@ -646,7 +696,7 @@ class GitlabRetriever(GitRetriever):
             # Use remote default branch ref
             remote_branch_ref = remote + '/' + default_branch
             commit_hash_base = get_common_ancestor_commit_hash(remote_branch_ref)
-            if commit_hash_base is None:
+            if not commit_hash_base:
                 return None
             return commit_hash_base, commit_hash_head
 
@@ -665,7 +715,7 @@ class CircleCiRetriever(GitRetriever):
         default_branch = options.default_branch
 
         commit_hash_head = get_env_var('CIRCLE_SHA1')
-        if commit_hash_head is None:
+        if not commit_hash_head:
             return None
 
         # Check if base revision is provided to the environment, e.g.
@@ -684,7 +734,7 @@ class CircleCiRetriever(GitRetriever):
             return base_revision, commit_hash_head
         else:
             current_branch = get_env_var('CIRCLE_BRANCH')
-            if current_branch is None:
+            if not current_branch:
                 return None
             # Test all commits off of the default branch
             logger.verbose_print(
@@ -699,7 +749,7 @@ class CircleCiRetriever(GitRetriever):
             # Use remote default branch ref
             remote_branch_ref = remote + '/' + default_branch
             commit_hash_base = get_common_ancestor_commit_hash(remote_branch_ref)
-            if commit_hash_base is None:
+            if not commit_hash_base:
                 return None
             return commit_hash_base, commit_hash_head
 
@@ -716,10 +766,10 @@ class AzurePipelinesRetriever(GitRetriever):
     def get_commit_range(self) -> Optional[Tuple[str, str]]:  # noqa: D102
         # See: https://docs.microsoft.com/en-us/azure/devops/pipelines/build/variables?view=azure-devops&tabs=yaml#build-variables  # noqa: E501
         commit_hash_head = get_env_var('BUILD_SOURCEVERSION')
-        if commit_hash_head is None:
+        if not commit_hash_head:
             return None
         current_branch = get_env_var('BUILD_SOURCEBRANCHNAME')
-        if current_branch is None:
+        if not current_branch:
             return None
 
         base_branch = None
@@ -731,7 +781,7 @@ class AzurePipelinesRetriever(GitRetriever):
         if is_pull_request:
             # Test all commits off of the target branch
             target_branch = get_env_var('SYSTEM_PULLREQUEST_TARGETBRANCH')
-            if target_branch is None:
+            if not target_branch:
                 return None
             logger.verbose_print(
                 f"\ton pull request branch '{current_branch}': "
@@ -755,7 +805,7 @@ class AzurePipelinesRetriever(GitRetriever):
         # Use remote default branch ref
         remote_branch_ref = remote + '/' + base_branch
         commit_hash_base = get_common_ancestor_commit_hash(remote_branch_ref)
-        if commit_hash_base is None:
+        if not commit_hash_base:
             return None
         return commit_hash_base, commit_hash_head
 
@@ -774,19 +824,19 @@ class AppVeyorRetriever(GitRetriever):
         default_branch = options.default_branch
 
         commit_hash_head = get_env_var('APPVEYOR_REPO_COMMIT')
-        if commit_hash_head is None:
+        if not commit_hash_head:
             commit_hash_head = get_head_commit_hash()
-            if commit_hash_head is None:
+            if not commit_hash_head:
                 return None
 
         branch = get_env_var('APPVEYOR_REPO_BRANCH')
-        if branch is None:
+        if not branch:
             return None
 
         # Check if pull request
         if get_env_var('APPVEYOR_PULL_REQUEST_NUMBER', print_if_not_found=False):
             current_branch = get_env_var('APPVEYOR_PULL_REQUEST_HEAD_REPO_BRANCH')
-            if current_branch is None:
+            if not current_branch:
                 return None
             target_branch = branch
             logger.verbose_print(
@@ -794,10 +844,10 @@ class AppVeyorRetriever(GitRetriever):
                 f"will check commits off of target branch '{target_branch}'"
             )
             commit_hash_head = get_env_var('APPVEYOR_PULL_REQUEST_HEAD_COMMIT') or commit_hash_head
-            if commit_hash_head is None:
+            if not commit_hash_head:
                 return None
             commit_hash_base = get_common_ancestor_commit_hash(target_branch)
-            if commit_hash_base is None:
+            if not commit_hash_base:
                 return None
             return commit_hash_base, commit_hash_head
         else:
@@ -808,7 +858,7 @@ class AppVeyorRetriever(GitRetriever):
                 f"will check forked commits off of default branch '{default_branch}'"
             )
             commit_hash_base = get_common_ancestor_commit_hash(default_branch)
-            if commit_hash_base is None:
+            if not commit_hash_base:
                 return None
             return commit_hash_base, commit_hash_head
 
@@ -825,14 +875,14 @@ class GitHubRetriever(CommitDataRetriever):
     def get_commit_range(self) -> Optional[Tuple[str, str]]:  # noqa: D102
         # See: https://docs.gitlab.com/ee/ci/variables/predefined_variables.html
         self.github_token = get_env_var('GITHUB_TOKEN')
-        if self.github_token is None:
+        if not self.github_token:
             logger.print('Did you forget to include this in your workflow config?')
             logger.print('\n\tenv:\n\t\tGITHUB_TOKEN: ${{ secrets.GITHUB_TOKEN }}')
             return None
 
         # See: https://help.github.com/en/actions/configuring-and-managing-workflows/using-environment-variables  # noqa: E501
         event_payload_path = get_env_var('GITHUB_EVENT_PATH')
-        if event_payload_path is None:
+        if not event_payload_path:
             return None
         f = open(event_payload_path)
         self.event_payload = json.load(f)
@@ -840,7 +890,7 @@ class GitHubRetriever(CommitDataRetriever):
 
         # Get base & head commits depending on the workflow event type
         event_name = get_env_var('GITHUB_EVENT_NAME')
-        if event_name is None:
+        if not event_name:
             return None
         commit_hash_base = None
         commit_hash_head = None
@@ -873,26 +923,26 @@ class GitHubRetriever(CommitDataRetriever):
             return None
         return commit_hash_base, commit_hash_head
 
-    def get_commits(
+    def get_commits(  # noqa: D102
         self,
         base: str,
         head: str,
-        **kwargs,
-    ) -> Optional[List[CommitInfo]]:  # noqa: D102
+        **kwargs: Any,
+    ) -> Optional[List[CommitInfo]]:
         # Request commit data
         compare_url_template = self.event_payload['repository']['compare_url']
         compare_url = compare_url_template.format(base=base, head=head)
         connection = http.client.HTTPSConnection('api.github.com')
         headers = {
             'User-Agent': 'dco_check',
-            'Authorization': 'token ' + self.github_token,
+            'Authorization': 'token ' + (self.github_token or ''),
         }
         connection.request('GET', compare_url, headers=headers)
         response = connection.getresponse()
         if 200 != response.getcode():  # pragma: no cover
-            from pprint import pprint
+            from pprint import pformat
             logger.print('Request failed: compare_url')
-            logger.print('reponse:', pprint(response.read().decode()))
+            logger.print('reponse:', pformat(response.read().decode()))
             return None
 
         # Extract data
@@ -943,12 +993,12 @@ def process_commits(
         logger.verbose_print(
             '\t' + commit.hash + (' (merge commit)' if commit.is_merge_commit else '')
         )
-        logger.verbose_print('\t' + (commit.author_name or 'N/A'), (commit.author_email or 'N/A'))
+        logger.verbose_print('\t' + format_name_and_email(commit.author_name, commit.author_email))
         logger.verbose_print('\t' + commit.title)
         logger.verbose_print('\t' + '\n\t'.join(commit.body))
 
         # Check author name and email
-        if any(d is None for d in [commit.author_name, commit.author_email]):
+        if any(not d for d in [commit.author_name, commit.author_email]):
             infractions[commit.hash].append(
                 f'could not extract author data for commit: {commit.hash}'
             )
@@ -969,8 +1019,11 @@ def process_commits(
         # Extract sign off information
         sign_offs_name_email: List[Tuple[str, str]] = []
         for sign_off in sign_offs:
-            name, email = extract_name_and_email(sign_off)
-            logger.verbose_print('\t\t' + 'found sign-off:', name, email)
+            sign_off_result = extract_name_and_email(sign_off)
+            if not sign_off_result:
+                continue
+            name, email = sign_off_result
+            logger.verbose_print(f'\t\tfound sign-off: {format_name_and_email(name, email)}')
             if not is_valid_email(email):
                 infractions[commit.hash].append(f'invalid email: {email}')
             else:
@@ -1031,7 +1084,7 @@ def main(argv: Optional[List[str]] = None) -> int:
     # Detect CI
     # Use first one that applies
     retrievers = [
-        GitlabRetriever,
+        GitLabRetriever,
         GitHubRetriever,
         AzurePipelinesRetriever,
         AppVeyorRetriever,
@@ -1044,12 +1097,15 @@ def main(argv: Optional[List[str]] = None) -> int:
         if retriever.applies():
             commit_retriever = retriever
             break
+    if not commit_retriever:
+        logger.print('Could not find an applicable GitRetriever')
+        return 1
     logger.print('Detected:', commit_retriever.name())
 
     # Get default branch from remote if enabled
     if options.default_branch_from_remote:
         remote_default_branch = get_default_branch_from_remote(options.default_remote)
-        if remote_default_branch is None:
+        if not remote_default_branch:
             logger.print('Could not get default branch from remote')
             return 1
         options.default_branch = remote_default_branch
@@ -1057,7 +1113,7 @@ def main(argv: Optional[List[str]] = None) -> int:
 
     # Get range of commits
     commit_range = commit_retriever.get_commit_range()
-    if commit_range is None:
+    if not commit_range:
         return 1
     commit_hash_base, commit_hash_head = commit_range
 
